import fs from 'fs'
import awaitFs from 'await-fs'
import { bulksmsConfig } from '../config/bulksms'
import express from 'express'
import Player from '../models/player'
import Match from '../models/match'
import MatchList from '../models/matchList'

const sztm = express.Router()

sztm.get('/schedule', async (req, res) => {
    try{
        const { matchListId, startDate, endDate, place, category } = req.query
        
        const matchList = matchListId ? 
        await MatchList.findOne({ _id: matchListId }) : 
        await MatchList.findOne().sort({ imported: -1 })
        
        const query = { _id: { $in: matchList.matches } }
        if (place) query.place = place
        if (category) query.category = category
        if (startDate || endDate) { query.date = {} }
        if (startDate) {
            const startElems = startDate.match(/(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})/).slice(1, 7)
            const startDateParsed = new Date(`${startElems[0]}-${startElems[1]}-${startElems[2]} ${startElems[3]}:${startElems[4]}:${startElems[5]}`)
            query.date.$gte = startDateParsed
        }
        if (endDate) {
            const endElems = endDate.match(/(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})/).slice(1, 7)
            const endDateParsed = new Date(`${endElems[0]}-${endElems[1]}-${endElems[2]} ${endElems[3]}:${endElems[4]}:${endElems[5]}`)
            query.date.$lte = endDateParsed
        }
        
        const matches = await Match.find(query).sort({ date: 1 })
        const playerList = []
        matches.forEach(match => {
            if (match.player1) playerList.push(match.player1)
            if (match.player2) playerList.push(match.player2)
        })
        const players = await Player.find({ _id: { $in: playerList.players } })
        res.json({ matches, players })
        
        //const filteredMatches = matchList.matches.sort().filter()
    } catch (error) {
        res.status(400).json({ msg: error.toString() })
    }
})

sztm.post('/sms', async (req, res) => {
    
})

export default sztm