import express from 'express'
import pdfMake from 'pdfmake/build/pdfmake'
import pdfFonts from 'pdfmake/build/vfs_fonts'
import fs from 'fs'
import User from '../models/user'
pdfMake.vfs = pdfFonts.pdfMake.vfs

const users = express.Router()

users.get('/', (req, res) => {
  const dbUsers = User.find().lean()
  dbUsers.exec((err, users) => {
      if (err) {
        res.status(400).json({
            msg: err.toString()
        })
        return
      }

      return res.json({
          users
      })
  })
})

users.get('/pdf', async (req, res) => {
    try {
        const dbUsers = await User.find().lean().exec()
        const docDefinition = {
            content: [
                { text: 'Benutzerliste', style: 'header'},
                { table: {
                    headerRows: 1,
                    widths: ['20%', '*', '30%'],
                    body: Array.concat(
                        [['Benutzername', 'Name', 'Passwort-Hash']],
                        dbUsers.map((user) => {
                            return [user.username, user.name, user.password]
                        }))
                } }
            ],
            styles: {
                header: {
                    fontSize: 22,
                    bold: true
                }
            }
        }
        const pdfDocGenerator = pdfMake.createPdf(docDefinition)
        pdfDocGenerator.getBuffer((buffer) => {
            fs.writeFileSync('/usr/src/sztm_files/users.pdf', new Buffer(new Uint8Array(buffer)))
        })
        res.send("Alles paletti")
    } catch (error) {
        return res.json({ msg: error.toString() })
    }
})

users.get('/:username', (req, res) => {
    const { username } = req.params

    if (!username) {
        res.status(400).json({
            msg: 'Parameter username is required'
        })
        return
    }

    const dbUser = User.findOne({ username }).lean()
    dbUser.exec((err, user) => {
        if (err) {
            res.status(400).json({
                msg: err.toString()
            })
            return
        }

        return res.json({
            user: JSON.stringify(user)
        })
    })
})

users.post('/', (req, res) => {
  const { username, name, password } = req.body

  // return, if username or password are missing
  if (!username || !name || !password) {
    res.status(400).json({
      msg: 'Parameters username, name and password are required'
    })
    return
  }
  const user = new User({
      username,
      name,
      password
  })
  user.save((err) => {
      if (err) {
        res.status(400).json({
            msg: err.toString()
        })
        return
      }
      res.json({
        user_id: user._id
      })
  })
}) 

users.put('/', (req, res) => {
    const { username, name, password } = req.body

    // return, if username or password are missing
    if (!username || !name || !password) {
      res.status(400).json({
        msg: 'Parameters username, name and password are required'
      })
      return
    }
    
    User.findOne({ username }, (err, user) => {
        user.set({ username, name, password })
        user.save((err) => {
            if (err) {
              res.status(400).json({
                  msg: err.toString()
              })
              return
            }
            res.json({
              user_id: user._id
            })
        })
    })
})

users.delete('/:username', (req, res) => {
    const { username } = req.params

    User.findOne({ username }, (err, user) => {
        if (err) {
            res.status(400).json({
                msg: err.toString()
            })
            return
        }
        if (!user) {
            res.status(400).json({
                msg: "User not found."
            })
            return
        }
        User.deleteOne({ username }, (err) => {
            if (err) {
                res.status(400).json({
                    msg: err.toString()
                })
                return
            }
            res.json({
            })
        })
    })
})

export default users